@@ -585,14 +585,15 @@ class NaroNet_dataset(torch.utils.data.Dataset):
     def clusterPresence(self, clusters, IndexAndClass,ClusterThreshold, isTraining):
         ''' Obtain cluster map from each slide.'''
        
-        heatmapClusterPresence, labels = obtain_celltype_abundance_per_patient(self, IndexAndClass, clusters, ClusterThreshold)
-        
-        if not isTraining:
-            save_celltype_abundance_per_patient(self,IndexAndClass, clusters, heatmapClusterPresence, labels[str(clusters[0])], 
-                                                ['Phenotypes','Neighborhoods','Areas'],['P','N','A'])
-            h_all = {}
-            h_all[str(sum(clusters))] = stats.zscore(np.concatenate(([heatmapClusterPresence[str(clusters[i])] for i in range(len(clusters))]),axis=1),axis=1)
-            save_celltype_abundance_per_patient(self,IndexAndClass, [sum(clusters)], h_all, labels[str(clusters[0])], ['ALL'],['X'])
+        for clusterTHr in ClusterThreshold:
+            heatmapClusterPresence, labels = obtain_celltype_abundance_per_patient(self, IndexAndClass, clusters, clusterTHr)
+            
+            if not isTraining:
+                save_celltype_abundance_per_patient(self,IndexAndClass, clusters, heatmapClusterPresence, labels[str(clusters[0])], 
+                                                    ['Phenotypes','Neighborhoods','Areas'],['P','N','A'],clusterTHr)
+                h_all = {}
+                h_all[str(sum(clusters))] = stats.zscore(np.concatenate(([heatmapClusterPresence[str(clusters[i])] for i in range(len(clusters))]),axis=1),axis=1)
+                save_celltype_abundance_per_patient(self,IndexAndClass, [sum(clusters)], h_all, labels[str(clusters[0])], ['ALL'],['X'],clusterTHr)
 
         return heatmapClusterPresence, labels
 
@@ -923,7 +924,7 @@ class NaroNet_dataset(torch.utils.data.Dataset):
         Colormap=cm.jet_r(range(0,255,int(255/heatmapMarkerExpression.shape[0])))[:,:3]
 
         # Create ClusterMap
-        plt.close()
+        plt.close('all')
         plt.figure()
         heatmapMarkerExpression_Fig = sns.clustermap(heatmapMarkerExpression, vmin=-2, vmax=2,col_cluster=False, row_cluster=False, row_colors=Colormap,xticklabels=Superpixels_Names,yticklabels=celltypes_names, linewidths=0.5, cmap="Spectral_r")            
         heatmapMarkerExpression_Fig.savefig(osp.join(self.bioInsights_dir_cell_types,cell_type,'heatmap_MarkerExpression_nClusters_{}_iter_{}_Thr{}.png'.format(ClusterLevel,self.args['epochs'],ClusteringThreshold)),dpi=300) 
@@ -988,7 +989,9 @@ class NaroNet_dataset(torch.utils.data.Dataset):
         if len([i for i in os.listdir(self.bioInsights_dir_cell_types_Neigh) if 'Interactivity' in i])>0 and False:
             return
 
-        visualize_tsne_phenotypes(self, IndexAndClass,clusters)
+        
+        if self.args['TSNE_Perc_Pat']>0:
+            visualize_tsne_phenotypes(self, IndexAndClass,clusters)
 
         CropConfPheno, CropConfTissueComm, TissueArea_Conf = select_patches_from_cohort(self,IndexAndClass,clusters)                 
         
@@ -1009,16 +1012,16 @@ class NaroNet_dataset(torch.utils.data.Dataset):
         '''
             Visualize all the results.
         '''
-    
+
         # Obtain Neigh-to-Pheno, and Area-to-Neigh heatmap.
-        for ClusteringTrheshold in [0,90]:
-            Area_to_Neighborhood_to_Phenotype(self,clusters,IndexAndClass,ClusteringTrheshold)             
+        for ClusteringTrheshold in [0,50,75,90,99,99.9,99.99]:
+            Area_to_Neighborhood_to_Phenotype(self,clusters,IndexAndClass,ClusteringTrheshold)     
 
         # Obtain cell-types examples
-        self.ObtainPhenoExamples(IndexAndClass,clusters,[25,95])                
+        self.ObtainPhenoExamples(IndexAndClass,clusters,[25])                
         
         # Cell-types abundances
-        heatmapClusterPresence, labels = self.clusterPresence(clusters, IndexAndClass,50, isTraining=False)                        
+        heatmapClusterPresence, labels = self.clusterPresence(clusters, IndexAndClass,[50], isTraining=False)                        
         
         # Differential abundance analysis
         _, _, _, _, _ = differential_abundance_analysis(self, heatmapClusterPresence, labels, IndexAndClass,False)
