@@ -42,7 +42,7 @@ def calc_contrast_loss_prev(features,assignment_orig,device,args):
     return loss/assignment_orig.shape[1]
 
 
-def calc_contrast_loss(features,assignment_orig,device,args):
+def calc_contrast_loss_topBottomPerc(features,assignment_orig,device,args):
 
 
     # Number of patches that define the phenotype.
@@ -76,18 +76,71 @@ def calc_contrast_loss(features,assignment_orig,device,args):
         positives = torch.exp((torch.matmul(objective,assignment_orig[top_elem].T)/temp)) 
         loss += -torch.log(positives).mean()*temp       
 
-        # # Patches with highest confidence assignment 
-        # highest_conf_assignment = assignment_orig[:,ph].topk(pos_batch*10,0)[1]   
+        # combine feature dist and assignment
+        # highest_conf_assignment = (((1-feat_dist)/2)**2 + (assignment_orig[:,ph])**2).topk(pos_batch,1)[1]   
+        # negatives = torch.exp((torch.matmul(objective,assignment_orig[highest_conf_assignment.squeeze()].T)/temp))    
+        # loss += (torch.log(negatives)).mean()*temp
         
-        # # Patch with highest features distance from top-1
-        # bottom_val = feat_dist[:,highest_conf_assignment].topk(pos_batch,1,largest=False)[1].squeeze()
-        
-        # # Negative loss - patches with dissimilar features to the top-k patches but with high assignment confidence should have a dissimilar assignment.
-        # negatives = torch.exp((torch.matmul(objective,assignment_orig[highest_conf_assignment[bottom_val]].T)/temp))        
-        # loss += (torch.log(negatives)*(1-feat_dist[0,highest_conf_assignment[bottom_val]])/2).mean()*temp
+
+        # Patches with highest confidence assignment 
+        highest_conf_assignment = assignment_orig[:,ph].topk(pos_batch*2,0)[1]           
+        # Patch with highest features distance from top-1
+        bottom_val = feat_dist[:,highest_conf_assignment].topk(pos_batch,1,largest=False)[1].squeeze()
+        # Negative loss - patches with dissimilar features to the top-k patches but with high assignment confidence should have a dissimilar assignment.
+        negatives = torch.exp((torch.matmul(objective,assignment_orig[highest_conf_assignment[bottom_val]].T)/temp))        
+        loss += (torch.log(negatives)*(1-feat_dist[0,highest_conf_assignment[bottom_val]])/2).mean()*temp
         
     return loss/assignment_orig.shape[1]
 
+def calc_contrast_loss(features,assignment_orig,device,args):
+
+
+
+    # Number of patches going to 
+    pos_batch = max(min(int(assignment_orig.shape[0]*args['Perc_high_conf_patches']),assignment_orig.shape[0]),4,assignment_orig.shape[1])
+
+    # Calculate feature similarities
+    features = F.normalize(features.squeeze(), dim=1)    
+    assignment_orig = F.normalize(assignment_orig,dim=1)
+    temp = 0.07
+
+    loss = 0
+    for ph in range(assignment_orig.shape[1]):
+        
+        # Perfect assignment
+        objective = torch.zeros(assignment_orig.shape[1],device=device)
+        objective[ph] = 1
+
+        # Obtain top-k assignment that defines the TME
+        top_assignment = assignment_orig[:,ph].topk(pos_batch*10,0)[1]   
+        
+        # Feature distance to top-k
+        feat_dist = torch.matmul(features[top_assignment], features[top_assignment].T).sum(1)
+        
+        # Select most similar patches
+        top_elem = (feat_dist.topk(pos_batch,0)[1])
+        
+        # Positive loss - patches with similar features to the top-k patches should have the same assignment
+        positives = torch.exp((torch.matmul(objective,assignment_orig[top_assignment][top_elem].T)/temp)) 
+        loss += -torch.log(positives).mean()*temp       
+        
+
+        # combine feature dist and assignment
+        # highest_conf_assignment = (((1-feat_dist)/2)**2 + (assignment_orig[:,ph])**2).topk(pos_batch,1)[1]   
+        # negatives = torch.exp((torch.matmul(objective,assignment_orig[highest_conf_assignment.squeeze()].T)/temp))    
+        # loss += (torch.log(negatives)).mean()*temp
+        
+
+        # Patches with highest confidence assignment          
+        # bottom_val = feat_dist.topk(pos_batch*9,0,largest=False)[1]
+        # # Negative loss - patches with dissimilar features to the top-k patches but with high assignment confidence should have a dissimilar assignment.
+        # negatives = torch.exp((torch.matmul(objective,assignment_orig[top_assignment][bottom_val].T)/temp))        
+        # loss += torch.log(negatives).mean()*temp
+        # print('Positives: '+str((torch.log(positives).mean()*temp).item()*100)[:5]+' feat_pos: '+str(feat_dist[top_elem[0]].item())[:6]+'   -   Negative: '+str((torch.log(negatives).mean()*temp).item()*100)[:5]+' feat_neg: '+str(feat_dist[bottom_val[0]].item())[:6])
+        
+    return loss/assignment_orig.shape[1]
+
+
 def calc_patch_ent(s,device):    
     return ((-s/s.sum(dim=-1,keepdim=True) * torch.log(s/s.sum(dim=-1,keepdim=True) + 1e-15)).sum(dim=-1)/torch.log(torch.tensor(s.shape[1],dtype=torch.float32,device=device))).mean()   
 
