@@ -84,8 +84,8 @@ class ContrastiveLearningDataset_PCL(Dataset):
             image = io.imread(self.root_folder+self.image_list[idx])              
             image = image[:,:,self.Channels]
             if self.args['PCL_Z_Score'] and hasattr(self, 'mean'):
-                image -= np.expand_dims(np.expand_dims(self.mean,0),0)
-                image /= np.expand_dims(np.expand_dims(self.std,0),0)
+                image = image-np.expand_dims(np.expand_dims(self.mean,0),0)
+                image = image/np.expand_dims(np.expand_dims(self.std,0),0)
 
         # Load TIFF file
         elif self.image_list[idx].endswith('.tif') or self.image_list[idx].endswith('.tiff'): 
@@ -125,7 +125,7 @@ class ContrastiveLearningDataset_PCL(Dataset):
                     elif data[xIn:xIn+int(self.patch_size*self.alpha_L),yIn:yIn+int(self.patch_size*self.alpha_L),:].sum((2)).max()<=thr[0] and self.args['PCL_eliminate_White_Background']:                                        
                         images.append(data[xIn:xIn+int(self.patch_size*self.alpha_L),yIn:yIn+int(self.patch_size*self.alpha_L),:])
                         break
-                    elif self.args['PCL_eliminate_Black_Background']==False and self.args['PCL_eliminate_Black_Background']==False: 
+                    elif self.args['PCL_eliminate_Black_Background']==False and self.args['PCL_eliminate_White_Background']==False: 
                         images.append(data[xIn:xIn+int(self.patch_size*self.alpha_L),yIn:yIn+int(self.patch_size*self.alpha_L),:])
                         break        
         return images  
