@@ -309,7 +309,7 @@ def parameters(path, debug):
         args['lr_decay_step_size'] = 10000#max(int(args['epochs']/5),1)# if debug else hp.quniform('lr_decay_step_size', 2, 20, 1)        
         args['weight_decay'] = 4 if debug=='Index' else hp.choice('weight_decay',[0.1,0.01,0.001,0.0001,0]) if debug=='Object' else 0
         args['batch_size'] = 3 if debug=='Index' else hp.choice('batch_size', [2, 4, 8, 24]) if debug=='Object' else 24
-        args['lr'] = 3 if debug=='Index' else hp.choice('lr', [1,0.1,0.01,0.001,0.0001]) if debug=='Object' else 0.001
+        args['lr'] = 3 if debug=='Index' else hp.choice('lr', [1,0.1,0.01,0.001,0.001]) if debug=='Object' else 0.001
 
         # General
         args['training_MODE'] = 'TrainALL' # TrainALL, NestedCrossValidation, CrossValidation # Whether to use nested cross validation or cross validation.        
@@ -322,10 +322,10 @@ def parameters(path, debug):
         args['N_Phenotypes'] = 6#2 if debug=='Index' else hp.choice('clusters1',[5,10,15,20]) if debug=='Object' else 15     
         args['N_Neighborhoods'] = 8#1 if debug=='Index' else hp.choice('clusters2',[6,11,16,21]) if debug=='Object' else 11 
         args['N_Areas'] = 4#0 if debug=='Index' else hp.choice('clusters3',[2,4,7]) if debug=='Object' else 2      
-        args['n_hops_neighborhoods'] = 3 
+        args['n_hops_neighborhoods'] = 2 
         args['Phenotype_Learning'] = True  
         args['Neighborhood_Learning'] = True
-        args['Area_Learning'] = False
+        args['Area_Learning'] = True
         args['dropoutRate'] = 0# 1 if debug=='Index' else hp.choice('dropoutRate', [0.1, 0.2, 0.3,0.4]) if debug=='Object' else 0.2        
         args['attntnThreshold'] = 0# if debug=='Index' else hp.choice('attntnThreshold', [0,.2,.4,.6,.8]) if debug=='Object' else 0  
         args['1Patch1Cluster'] = False# if debug=='Index' else hp.choice('attntnThreshold', [0,.2,.4,.6,.8]) if debug=='Object' else 0  
@@ -349,9 +349,9 @@ def parameters(path, debug):
         # Patch contrastive learning parameters
         args['PCL_CNN_Architecture']='resnet50' # or resnet18
         args['PCL_N_Workers']=8 # Number of data loading workers 
-        args['PCL_Epochs']=80 # Number of total epoch to run
+        args['PCL_Epochs']=250 # Number of total epoch to run
         args['PCL_N_Crops_per_Image']=30 # Number of crops chosen per image
-        args['PCL_Patch_Size']=15 # Size of patches in pixels
+        args['PCL_Patch_Size']=30 # Size of patches in pixels
         args['PCL_Stride']=0 # Size of stride between consecutive patches
         args['PCL_Alpha_L']=1.15 # size ratio between image crop and image patch
         args['PCL_Z_Score']= True # Whether to apply z score per channel/marker
@@ -360,7 +360,7 @@ def parameters(path, debug):
         args['PCL_Out_Dimensions']= 128 # Feature dimensions of patch
         args['PCL_Learning_Rate']= 0.0003 # Learning Rate
         args['PCL_Temperature']= 0.07 # Softmax temperature    
-        args['PCL_eliminate_Black_Background'] = False 
+        args['PCL_eliminate_Black_Background'] = True 
         args['PCL_eliminate_White_Background'] = False        
         args['PCL_Color_perturbation_Augmentation'] = False # Whether to use color normalization augmentation in H&E white-field microscopy images. Used to force PCL to learn morphological features and avoid learning color staining features. 
         args['PCL_GPU_INDEX']= torch.device('cuda:0') # GPU where the training is carried out 
@@ -373,16 +373,16 @@ def parameters(path, debug):
 
         # Optimization Parameters
         args['NaroNet_n_workers'] = 1
-        args['epochs'] = 300# if debug else hp.quniform('epochs', 5, 25, 1)
+        args['epochs'] = 100# if debug else hp.quniform('epochs', 5, 25, 1)
         args['lr_decay_factor'] = 0.1# if debug else hp.uniform('lr_decay_factor', 0, 0.75)
         args['lr_decay_step_size'] = 10000#max(int(args['epochs']/5),1)# if debug else hp.quniform('lr_decay_step_size', 2, 20, 1)        
         args['weight_decay'] = 4 if debug=='Index' else hp.choice('weight_decay',[0.1,0.01,0.001,0.0001,0]) if debug=='Object' else 0
-        args['batch_size'] = 3 if debug=='Index' else hp.choice('batch_size', [2, 4, 8, 24]) if debug=='Object' else 24
+        args['batch_size'] = 3 if debug=='Index' else hp.choice('batch_size', [2, 4, 8, 64]) if debug=='Object' else 64
         args['lr'] = 3 if debug=='Index' else hp.choice('lr', [1,0.1,0.01,0.001,0.0001]) if debug=='Object' else 0.001
 
         # General
-        args['training_MODE'] = 'TrainALL' # TrainALL, NestedCrossValidation, CrossValidation # Whether to use nested cross validation or cross validation.        
-        args['folds'] = 1
+        args['training_MODE'] = 'CrossValidation' # TrainALL, NestedCrossValidation, CrossValidation # Whether to use nested cross validation or cross validation.        
+        args['folds'] = 24
         args['device'] = 'cuda:0'
         args['Batch_Normalization'] = True
         args['dataAugmentationPerc'] = 0 #0 if debug=='Index' else hp.choice("dataAugmentationPerc", [0,0.0001,0.001]) if debug=='Object' else 0  
@@ -391,6 +391,7 @@ def parameters(path, debug):
         args['N_Phenotypes'] = 4#2 if debug=='Index' else hp.choice('clusters1',[5,10,15,20]) if debug=='Object' else 15     
         args['N_Neighborhoods'] = 6#1 if debug=='Index' else hp.choice('clusters2',[6,11,16,21]) if debug=='Object' else 11 
         args['N_Areas'] = 2#0 if debug=='Index' else hp.choice('clusters3',[2,4,7]) if debug=='Object' else 2      
+        args['n_hops_neighborhoods'] = 3
         args['Phenotype_Learning'] = True  
         args['Neighborhood_Learning'] = True
         args['Area_Learning'] = True
